@@ -1,5 +1,5 @@
 ##
-#  Copyright (c) 2008-2013 Fred Hutchinson Cancer Research Center
+#  Copyright (c) 2008-2014 Fred Hutchinson Cancer Research Center
 # 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -28,42 +28,83 @@
  	for(i in 1:fcount)
  			{	# Match the operator
  				fop  <- switch(EXPR=fmat[i,2],
+
+								#
+								# These operators require a data value
+								#
+
  								"EQUALS"="eq",
  								"EQUAL"="eq",
+ 								"DATE_EQUAL"="dateeq",
+
+ 								"NEQ"="neq",
  								"NOT_EQUALS"="neq",
  								"NOT_EQUAL"="neq",
+ 								"DATE_NOT_EQUAL"="dateneq",
+
  								"NOT_EQUAL_OR_NULL"="neqornull",
  								"NOT_EQUAL_OR_MISSING"="neqornull",
- 								"DATE_EQUAL"="dateeq",
- 								"DATE_NOT_EQUAL"="dateneq",
- 								"DATE_GREATER_THAN_OR_EQUAL"="dategte",
- 								"DATE_LESS_THAN_OR_EQUAL"="datelte",
- 								"IS_MISSING"="isblank",
- 								"MISSING"="isblank",
- 								"IS_NOT_MISSING"="isnonblank",
- 								"NOT_MISSING"="isnonblank",
+
+ 								"GT"="gt",
  								"GREATER_THAN"="gt",
+ 								"DATE_GT"="dategt",
+ 								"DATE_GREATER_THAN"="dategt",
+
+ 								"GTE"="gte",
  								"GREATER_THAN_OR_EQUAL_TO"="gte",
  								"GREATER_THAN_OR_EQUAL"="gte",
+ 								"DATE_GTE"="dategte",
+ 								"DATE_GREATER_THAN_OR_EQUAL"="dategte",
+
+ 								"LT"="lt",
  								"LESS_THAN"="lt",
+ 								"DATE_LT"="datelt",
+ 								"DATE_LESS_THAN"="datelt",
+
+ 								"LTE"="lte",
  								"LESS_THAN_OR_EQUAL_TO"="lte",
  								"LESS_THAN_OR_EQUAL"="lte",
- 								"CONTAINS"="contains",
- 								"DOES_NOT_CONTAIN"="doesnotcontain",
+ 								"DATE_LTE"="datelte",
+ 								"DATE_LESS_THAN_OR_EQUAL"="datelte",
+
  								"STARTS_WITH"="startswith",
  								"DOES_NOT_START_WITH"="doesnotstartwith",
- 								"EQUALS_ONE_OF"="in",
+
+ 								"CONTAINS"="contains",
+ 								"DOES_NOT_CONTAIN"="doesnotcontain",
+
+								"CONTAINS_ONE_OF"="containsoneof",
+								"CONTAINS_NONE_OF"="containsnoneof",
+
  								"IN"="in",
+ 								"EQUALS_ONE_OF"="in",
+
+								"NOT_IN"="notin",
+								"EQUALS_NONE_OF"="notin",
+
+								"BETWEEN"="between",
+								"NOT_BETWEEN"="notbetween",
+
+								"MEMBER_OF"="memberof",
+
+								#
+								# These are the "no data value" operators
+								#
+
+ 								"ISBLANK"="isblank",
+ 								"IS_MISSING"="isblank",
+ 								"MISSING"="isblank",
+ 								"NON_BLANK"="isnonblank",
+ 								"IS_NOT_MISSING"="isnonblank",
+ 								"NOT_MISSING"="isnonblank",
+
 								"MV_INDICATOR"="hasmvvalue",
 								"QC_VALUE"="hasmvvalue",
 								"NO_MV_INDICATOR"="nomvvalue",
 								"NOT_QC_VALUE"="nomvvalue",
-								"EQUALS_NONE_OF"="notin",
-								"NOT_IN"="notin",
-								"MEMBER_OF"="memberof",
-								"CONTAINS_ONE_OF"="containsoneof",
-								"CONTAINS_NONE_OF"="containsnoneof")
-								
+
+								)
+
  				if(is.null(fop)==TRUE) stop ("Invalid operator name.")
  				# url encode column name and value
  				colnam <- curlEscape(fmat[i,1])
